import machine
import utime
from dht20 import DHT20
from ssd1306 import SSD1306_I2C
import neopixel

NUM_PIXELS = 9
PIN = 28

np = neopixel.NeoPixel(machine.Pin(PIN), NUM_PIXELS)

BRIGHTNESS = 0.5

np.fill((0, 0, 0))
np.write()

def set_color(color):
    np.fill([int(c*BRIGHTNESS) for c in color])
    np.write()

color = (0, 0, 255)  
set_color(color)

# I2C for DHT20 sensor
i2c1_sda = machine.Pin(2)
i2c1_scl = machine.Pin(3)
i2c1 = machine.I2C(1, sda=i2c1_sda, scl=i2c1_scl)

# DHT20 sensor setup
dht20 = DHT20(0x38, i2c1)

# I2C for SSD1306 OLED display
i2c = machine.I2C(0, sda=machine.Pin(0), scl=machine.Pin(1), freq=400000)
oled = SSD1306_I2C(128, 64, i2c)

# Button setup
button_pin1 = machine.Pin(6, machine.Pin.IN, machine.Pin.PULL_UP)
button_pin2 = machine.Pin(8, machine.Pin.IN, machine.Pin.PULL_UP)
button_pin3 = machine.Pin(10, machine.Pin.IN, machine.Pin.PULL_UP)
button_pin4 = machine.Pin(12, machine.Pin.IN, machine.Pin.PULL_UP)
prev_button_state1 = button_pin1.value()
prev_button_state2 = button_pin2.value()
prev_button_state3 = button_pin3.value()
prev_button_state4 = button_pin4.value()

# Variables to track display mode
display_mode = 0
max_display_modes = 4

def switch_display_mode1():
    global display_mode
    display_mode = 0

def switch_display_mode2():
    global display_mode
    display_mode = 1

def switch_display_mode3():
    global display_mode
    display_mode = 2

def switch_display_mode4():
    global display_mode
    display_mode = 3
    
def celsius_to_fahrenheit(celsius):
    return (celsius * 9/5) + 32

while True:
    # Read temperature and humidity from DHT20 sensor
    measurements = dht20.measurements
    temperature_celsius = measurements['t']
    temperature_fahrenheit = celsius_to_fahrenheit(temperature_celsius)
    humidity = measurements['rh']

    # Clear OLED display
    oled.fill(0)

    # Display content based on current display mode
    if display_mode == 0:
        oled.text("Temperature:", 0, 0)
        oled.text(f"{temperature_celsius} C", 0, 16)
        oled.text(f"{temperature_fahrenheit} F", 0, 32)
        oled.text(f"Humidity:{humidity} %RH", 0, 48)
        oled.text(f"{humidity} %RH", 0, 64)
    elif display_mode == 1:
        # Get the current date
        rtc = machine.RTC()
        datetime = rtc.datetime()

        year = datetime[0]
        month = datetime[1]
        day = datetime[2]

        # Format the date string
        date_str = "{:04d}-{:02d}-{:02d}".format(year, month, day)

        oled.text("Date", 0, 0)
        oled.text(date_str, 0, 20)
    elif display_mode == 2:
        oled.text("Fab Presentation", 0, 0)
        oled.text("6/14", 0, 16)
    elif display_mode == 3:
        oled.text("Local Doc 6/21 ", 0, 0)
        oled.text("Global Doc 6/28 ", 0, 16)

    # Show OLED display
    oled.show()

    # Check button states and switch display mode if pressed
    button_state1 = button_pin1.value()
    if button_state1 != prev_button_state1 and button_state1 == 1:
        switch_display_mode1()
    prev_button_state1 = button_state1

    button_state2 = button_pin2.value()
    if button_state2 != prev_button_state2 and button_state2 == 1:
        switch_display_mode2()
    prev_button_state2 = button_state2

    button_state3 = button_pin3.value()
    if button_state3 != prev_button_state3 and button_state3 == 1:
        switch_display_mode3()
    prev_button_state3 = button_state3

    button_state4 = button_pin4.value()
    if button_state4 != prev_button_state4 and button_state4 == 1:
        switch_display_mode4()
    prev_button_state4 = button_state4

    # Delay for 1 second
    utime.sleep(.3)
